AE summary table
Usage
gt_ae_summary(
outdata,
source,
analysis,
title = c("analysis", "observation", "population"),
footnotes = NULL
)Arguments
- outdata
An
outdataobject created byprepare_ae_specific().- source
A character value of the data source.
- analysis
One of analysis name existing at
outdata$meta$analysis- title
Term "analysis", "observation"and "population") for collecting title from metadata or a character vector of table titles.
- footnotes
A character vector of table footnotes.
Examples
library(gt)
#' # Define metadata
adsl <- forestly::forestly_adsl
adae <- forestly::forestly_adae
adsl$TRT01A <- factor(
adsl$TRT01A,
levels = c("Xanomeline Low Dose", "Placebo"),
labels = c("Low Dose", "Placebo")
)
adae$TRTA <- factor(
adae$TRTA,
levels = c("Xanomeline Low Dose", "Placebo"),
labels = c("Low Dose", "Placebo")
)
analysis_plan <- metalite::plan(
analysis = "ae_summary",
population = "apat",
observation = "wk12",
parameter = "any;rel;ser"
)
meta <- metalite::meta_adam(observation = adae, population = adsl) |>
metalite::define_plan(analysis_plan) |>
metalite::define_population(
name = "apat",
var = c(
"USUBJID", "SAFFL", "TRT01A", "TRTDUR",
"SITEID", "SEX", "RACE", "AGE"
),
group = "TRT01A",
subset = SAFFL == "Y",
label = "All Participants as Treated"
) |>
metalite::define_observation(
name = "wk12",
var = c(
"USUBJID", "SAFFL", "TRTA", "AEDECOD", "AEBODSYS", "AEREL",
"AESER", "AEOUT", "AEACN", "AESDTH", "ASTDT", "AENDT"
),
group = "TRTA",
subset = SAFFL == "Y",
label = "Weeks 0 to 12"
) |>
metalite::define_parameter(
name = "any",
term1 = "",
term2 = "",
var = "AEDECOD",
soc = "AEBODSYS",
label = "All AEs"
) |>
metalite::define_parameter(
name = "rel",
term1 = "Drug-Related",
term2 = "",
subset = AEREL %in% c("POSSIBLE", "PROBABLE"),
var = "AEDECOD",
soc = "AEBODSYS",
label = "Drug-related AEs"
) |>
metalite::define_parameter(
name = "ser",
term1 = "Serious",
term2 = "",
subset = AESER == "Y",
var = "AEDECOD",
soc = "AEBODSYS",
label = "Serious AEs"
) |>
metalite::define_analysis(
name = "ae_summary",
title = "Adverse Event Summary"
) |>
metalite::meta_build()
outdata <- prepare_ae_summary(meta,
population = "apat",
observation = "wk12",
parameter = "any;rel;ser"
)
#> any
#> rel
#> ser
outdata |>
format_ae_summary() |>
gt_ae_summary(
analysis = "ae_summary",
source = "Source: [CDISCpilot: adam-adsl; adae]"
)
#> [1] "Adverse Event Summary" "Weeks 0 to 12"
#> [3] "All Participants as Treated"
Adverse Event Summary
Weeks 0 to 12
All Participants as Treated
n
(%)
n
(%)
n
(%)
aDetermined by the investigator to be related to the drug.
Source: [CDISCpilot: adam-adsl; adae]