powered by
Prepare datasets for AE listing
prepare_ae_listing(meta, analysis, population, observation, parameter)
A list of analysis datasets needed for AE listing.
A metadata object created by metalite.
Analysis name from meta.
meta
A character value of population term name. The term name is used as key to link information.
A character value of observation term name. The term name is used as key to link information.
A character value of parameter term name. The term name is used as key to link information.
meta <- meta_ae_example() str(prepare_ae_listing(meta, "ae_listing", "apat", "wk12", "ser"))
Run the code above in your browser using DataLab