powered by
Prepare datasets for AE specific subgroup analysis
prepare_ae_specific_subgroup( meta, population, observation, parameter, subgroup_var, subgroup_header = c(meta$population[[population]]$group, subgroup_var), components = c("soc", "par"), display_subgroup_total = TRUE )
A list of analysis datasets needed for AE specific subgroup analysis.
A metadata object created by metalite.
A character value of population term name. The term name is used as key to link information.
A character value of observation term name. The term name is used as key to link information.
A character value of parameter term name. The term name is used as key to link information.
A character value of subgroup variable name in observation data saved in meta$data_observation.
meta$data_observation
A character vector for column header hierarchy. The first element will be the first level header and the second element will be second level header.
A character vector of components name.
Logical. Display total column for subgroup analysis or not.
meta <- meta_ae_example() prepare_ae_specific_subgroup(meta, "apat", "wk12", "rel", subgroup_var = "SEX")$data
Run the code above in your browser using DataLab