powered by
Prepare datasets for AE summary
prepare_ae_summary(meta, population, observation, parameter, ...)
A list of analysis datasets needed for AE summary.
A metadata object created by metalite.
A character value of population term name. The term name is used as key to link information.
A character value of observation term name. The term name is used as key to link information.
A character value of parameter term name. The term name is used as key to link information.
Additional arguments passed to prepare_ae_specific().
prepare_ae_specific()
meta <- meta_ae_example() prepare_ae_summary( meta, population = "apat", observation = "wk12", parameter = "any;rel;ser" )
Run the code above in your browser using DataLab